==> v3.0.1.zip: loader-plugin/README.md <==
# getBible Loader (3.0.1)

### The Joomla plugin from [getBible.net](https://getbible.net/joomla) to load of the Scriptures in your website content.

Ading the [getBible Loader Script](https://git.vdm.dev/getBible/loader) the the header of your website, we are adding the ability to your Joomla website to add Scriptures to your content very easily.

## How?

- Download the plugin [here](https://git.vdm.dev/getBible/loader-plugin/archive/master.zip).
- Install the plugin on your Joomla 3/4/5 website.
- Add a class `getBible` to any element (in your content) that contains a Scripture references like this:

   ```html
   <ul>
     <li class="getBible">John 3:16</li>
     <li class="getBible">1 John 3:16-19,22</li>
     <!-- Add more elements as needed -->
   </ul>
   ```
- Follow these [reference naming](https://git.vdm.dev/getBible/loader#scripture-reference-formatting) conventions.
- There is also [customization option](https://git.vdm.dev/getBible/loader#utilizing-data-attributes) available.
- For more details got to the [Biblekit documentation](https://getbible.net/loader) page.

> Support can be found at our [community support area](https://git.vdm.dev/getBible/support).

# Build Details

+ *Company*: [Vast Development Method](https://getbible.net)
+ *Author*: [Llewellyn van der Merwe](mailto:joomla@vdm.io)
+ *Name*: [getBible Loader](https://getbible.net)
+ *First Build*: 3rd December, 2015
+ *Last Build*: 28th November, 2023
+ *Version*: 3.0.1
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

> This **plugin** was build with a Joomla [Automated Component Builder](https://www.joomlacomponentbuilder.com).
> Developed by [Llewellyn van der Merwe](mailto:joomla@vdm.io)

==> v5.0.9.zip: loader-plugin/README.md <==
# getBible Loader (3.0.3)

### The Joomla plugin from [getBible.net](https://getbible.net/joomla) to load of the Scriptures in your website content.

Ading the [getBible Loader Script](https://git.vdm.dev/getBible/loader) the the header of your website, we are adding the ability to your Joomla website to add Scriptures to your content very easily.

## How?

- Download the plugin [here](https://git.vdm.dev/getBible/loader-plugin/archive/master.zip).
- Install the plugin on your Joomla 3/4/5 website.
- Add a class `getBible` to any element (in your content) that contains a Scripture references like this:

   ```html
   <ul>
     <li class="getBible">John 3:16</li>
     <li class="getBible">1 John 3:16-19,22</li>
     <!-- Add more elements as needed -->
   </ul>
   ```
- Follow these [reference naming](https://git.vdm.dev/getBible/loader#scripture-reference-formatting) conventions.
- There is also [customization option](https://git.vdm.dev/getBible/loader#utilizing-data-attributes) available.
- For more details got to the [Biblekit documentation](https://getbible.net/loader) page.

> Support can be found at our [community support area](https://git.vdm.dev/getBible/support).

# Build Details

+ *Company*: [Vast Development Method](https://getbible.net)
+ *Author*: [Llewellyn van der Merwe](mailto:joomla@vdm.io)
+ *Name*: [getBible Loader](https://getbible.net)
+ *First Build*: 3rd December, 2015
+ *Last Build*: 8th March, 2024
+ *Version*: 3.0.3
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

> This **plugin** was build with a Joomla [Automated Component Builder](https://www.joomlacomponentbuilder.com).
> Developed by [Llewellyn van der Merwe](mailto:joomla@vdm.io)
